# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawMeetingBuddySharesClient, RawMeetingBuddySharesClient


class MeetingBuddySharesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawMeetingBuddySharesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawMeetingBuddySharesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawMeetingBuddySharesClient
        """
        return self._raw_client

    def list_meeting_buddy_share_links(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Any]]:
        """
        List all share links for a meeting session.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Any]]
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_shares.list_meeting_buddy_share_links(
            session_id="session_id",
        )
        """
        _response = self._raw_client.list_meeting_buddy_share_links(session_id, request_options=request_options)
        return _response.data

    def revoke_meeting_buddy_share_link(
        self, token_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Any]:
        """
        Revoke a share link by its ID.

        Parameters
        ----------
        token_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        from aitronos import Aitronos

        client = Aitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.meeting_buddy_shares.revoke_meeting_buddy_share_link(
            token_id="token_id",
        )
        """
        _response = self._raw_client.revoke_meeting_buddy_share_link(token_id, request_options=request_options)
        return _response.data


class AsyncMeetingBuddySharesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawMeetingBuddySharesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawMeetingBuddySharesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawMeetingBuddySharesClient
        """
        return self._raw_client

    async def list_meeting_buddy_share_links(
        self, session_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.List[typing.Dict[str, typing.Any]]:
        """
        List all share links for a meeting session.

        Parameters
        ----------
        session_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.List[typing.Dict[str, typing.Any]]
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_shares.list_meeting_buddy_share_links(
                session_id="session_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_meeting_buddy_share_links(session_id, request_options=request_options)
        return _response.data

    async def revoke_meeting_buddy_share_link(
        self, token_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Dict[str, typing.Any]:
        """
        Revoke a share link by its ID.

        Parameters
        ----------
        token_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Dict[str, typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from aitronos import AsyncAitronos

        client = AsyncAitronos(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.meeting_buddy_shares.revoke_meeting_buddy_share_link(
                token_id="token_id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.revoke_meeting_buddy_share_link(token_id, request_options=request_options)
        return _response.data
